## Style rules {docsify-ignore}

There is `no need to add styles` to the DOM elements generated by the components because each component has a predefined style to implement. However, if you need to add a style for a special case, it is useful to know what you can and what you cannot do.

### Z-indexing

Some events can cause items to `overlap` each other, so it is useful to set a `z-index` to define an order of priority and not cause strange overlaps.

```css
.muuri-item {
  z-index: 1;
}
.muuri-item-dragging {
  z-index: 3;
}
.muuri-item-releasing {
  z-index: 2;
}
.muuri-item-hidden {
  z-index: 0;
}
```

### MuuriComponent

- The MuuriComponent element must be "positioned" meaning that it's CSS position property must be set to `relative`, `absolute` or `fixed`. If no position is provided the default one is `relative`.

```css
.muuri {
  position: relative;
}
```

### Item

- The item (outer) elements must have their CSS position set to `absolute` and their display property set to `block`, these properties are setted by the MuuriComponent.
- The item elements must not have any CSS `transitions` or `animations` applied to them.

### Simple style implementation

Here is a simple example.

```jsx
const Item = () => (
  <div class="item">
    <div class="item-content">
      I'm an item.
    </div>
  </div>
)
```

```css
.item {
  width: 100px;
  height: 100px;
  margin: 5px;
  z-index: 1;
}
.item.muuri-item-dragging {
  z-index: 3;
}
.item.muuri-item-releasing {
  z-index: 2;
}
.item.muuri-item-hidden {
  z-index: 0;
}
.item-content {
  position: relative;
  width: 100%;
  height: 100%;
}
```